@@ -29,7 +29,8 @@ struct type_pass *pass;
     complex *sbarray, *sbptr;
     extern int do_accounting;
 
-    msg  ("Subgroup = %c",0, pass->pass_data[0].fgroup);
+    msg  ("Baseline %c%c subgroup %c", 1, 
+           param->baseline[0], param->baseline[1], pass->pass_data[0].fgroup);
 
                                         /* Form control block for this pass */
     if (generate_cblock (root->ovex, param, pass) != 0)     
