@@ -144,8 +144,8 @@ struct type_pass *pass;
                 z = c_zero ();
                                   /* calculate location of this tabular point */
                 sbd = status.max_delchan + isbd - 2;
-                mbd = status.mbd_max_global + (imbd - 2) * status.mbd_sep;
-                dr = status.dr_max_global + (idr - 2) * status.rate_sep;
+                mbd = status.mbd_max_global + 0.5 * (imbd - 2) * status.mbd_sep;
+                dr = status.dr_max_global   + 0.5 * (idr - 2) * status.rate_sep;
 
                 msg ("[interp]dr %le mbd %le sbd %d sbd_max(ns) %10.6f", -1,
                      dr,mbd,sbd,status.sbd_max);
@@ -183,8 +183,8 @@ struct type_pass *pass;
 
                                     // calculate location of maximum in actual coords
     sbdel = status.max_delchan  + xi[0];
-    mbd = status.mbd_max_global + xi[1] * status.mbd_sep;
-    dr = status.dr_max_global   + xi[2] * status.rate_sep;
+    mbd = status.mbd_max_global + xi[1] * 0.5 * status.mbd_sep;
+    dr = status.dr_max_global   + xi[2] * 0.5 * status.rate_sep;
     
     msg ("max555 found amp %lf at %lf %lf %le", 1,
           drfmax, sbdel, mbd, dr);
