@@ -1380,6 +1380,10 @@ struct type_221 **t221)
     sprintf (buf, "Pcal rate: %.3E,  %.3E  (us/s)", 
                         fringe.t207->ref_pcrate, fringe.t207->rem_pcrate);
     psleft (0.5, ypos, buf);
+    sprintf (buf, "sb window (us)");
+    psleft (0.82, ypos, buf);
+    sprintf (buf, "%8.3lf %8.3lf", param.win_sb[0], param.win_sb[1]);
+    psleft (0.92, ypos, buf);
     ypos -= 0.01;
     psleft (0.0, ypos, "amp/seg (%)");
     sprintf (buf,"%.1f",status.timerms_amp);
@@ -1396,6 +1400,10 @@ struct type_221 **t221)
     else
         sprintf (buf, "SampCntNorm: disabled");
     psleft (0.65, ypos, buf);
+    sprintf (buf, "mb window (us)");
+    psleft (0.82, ypos, buf);
+    sprintf (buf, "%8.3lf %8.3lf", param.win_mb[0], param.win_mb[1]);
+    psleft (0.92, ypos, buf);
     ypos -= 0.01;
     psleft (0.0, ypos, "ph/frq (deg)");
     sprintf (buf,"%.1f",status.freqrms_phase);
@@ -1409,6 +1417,10 @@ struct type_221 **t221)
     srate = 1e-6/param.samp_period + 0.5;
     sprintf (buf, "Sample rate(MSamp/s): %d", srate);
     psleft (0.5, ypos, buf);
+    sprintf (buf, "dr window (ns/s)");
+    psleft (0.82, ypos, buf);
+    sprintf (buf, "%8.3lf %8.3lf", 1e3 * param.win_dr[0], 1e3 * param.win_dr[1]);
+    psleft (0.92, ypos, buf);
     ypos -= 0.01;
     psleft (0.0, ypos, "amp/frq (%)");
     sprintf (buf,"%.1f",status.freqrms_amp);
@@ -1425,11 +1437,12 @@ struct type_221 **t221)
     psleft (0.65, ypos, buf);
                                     // print coherence time if non-infinite
     if (pass->control.t_cohere > 0.0)
-            {
-            sprintf (buf,"t_cohere %.1f", pass->control.t_cohere);
-            psleft (0.75, ypos, buf);
-            }
+        sprintf (buf,"t_cohere (s) %.1f", pass->control.t_cohere);
+    else
+        sprintf (buf, "t_cohere infinite");
+    psleft (0.75, ypos, buf);
     ypos = 0.025;
+
     if (test_mode) strcpy (output_filename, "Suppressed by test mode");
     else strcpy (output_filename, fringename);
                                         /* recreate input filename from output */
