@@ -164,6 +164,9 @@ struct type_pass *pass;
                 }                   // end of fr loop
             else
                 {                   // process all tones in multitone mode
+                pcphas[stn] = (stn == 0) ? pass->control.pc_phase[j].ref
+                                         : pass->control.pc_phase[j].rem;
+                status.pc_offset[fr][stn] = (pcphas[stn] != NULLFLOAT) ? pcphas[stn] : 0.0;
                                     // assume for now that all ovex channels the same spacing
                 pcfreq_hz = fmod (pass->pass_data[fr].frequency * 1e6
                                 - ovex->st[n].channels[0].pcal_base_freq,
